==> bouml_2.2.2.tar.gz: bouml_2.2.2/src/dialog/SimpleRelationDialog.cpp <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#include <qgrid.h> 
#include <qlabel.h>
#include <qpushbutton.h>
#include <qcombobox.h> 
#include <qmessagebox.h>
#include <qvbox.h> 

#include "SimpleRelationDialog.h"
#include "SimpleRelationData.h"
#include "BrowserSimpleRelation.h"
#include "UmlWindow.h"
#include "KeyValueTable.h"
#include "UmlPixmap.h"
#include "DialogUtil.h"
#include "strutil.h"

SimpleRelationDialog::SimpleRelationDialog(SimpleRelationData * r,
					   const QPoint & p)
    : MyTabDialog(p, r->get_browser_node()), rel(r) {  
  bool visit = !hasOkButton();
  
  UmlCode type = rel->get_type();
  
  // general tab
  
  BrowserNode * bn = rel->get_browser_node();
  QGrid * grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);

  switch (rel->get_type()) {
  case UmlInherit:
    setCaption("Generalisation dialog");
    break;
  case UmlDependOn:
    setCaption("Dependency dialog");
    break;
  default:
    setCaption("unknown relation dialog");
    break;
  }
  
  new QLabel("from : ", grid);
  new QLabel(rel->get_start_node()->full_name(TRUE), grid);
  new QLabel("to : ", grid);
  new QLabel(rel->get_end_node()->full_name(TRUE), grid);
  
  new QLabel("stereotype : ", grid);
  edstereotype = new QComboBox(!visit, grid);
  edstereotype->insertItem(rel->get_stereotype());
  if (! visit) {
    edstereotype->insertStringList(rel->get_start_node()->default_stereotypes(type));
    edstereotype->setAutoCompletion(TRUE);
  }
  edstereotype->setCurrentItem(0);
  QSizePolicy sp = edstereotype->sizePolicy();
  sp.setHorData(QSizePolicy::Expanding);
  edstereotype->setSizePolicy(sp);
  
  QVBox * vtab = new QVBox(grid);
  new QLabel("description :", vtab);
  if (! visit)
    connect(new SmallPushButton("Editor", vtab), SIGNAL(clicked()),
	    this, SLOT(edit_description()));
  comment = new MultiLineEdit(grid);
  comment->setReadOnly(visit);
  comment->setText(bn->get_comment());
  QFont font = comment->font();
  font.setFamily("Courier");
  font.setFixedPitch(TRUE);
  comment->setFont(font);
  
  addTab(grid, "Uml");
  
  // USER : list key - value
  
  grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  kvtable = new KeyValuesTable(bn, grid, visit);
  addTab(grid, "User");
}

void SimpleRelationDialog::edit_description() {
  edit(comment->text(), "simplerelation_description",
       rel, TxtEdit, this, (post_edit) post_edit_description);
}

void SimpleRelationDialog::post_edit_description(SimpleRelationDialog * d, QString s)
{
  d->comment->setText(s);
}

void SimpleRelationDialog::accept() {
  BrowserNode * bn = rel->get_browser_node();
  
  rel->set_stereotype(edstereotype->currentText().stripWhiteSpace());
  bn->set_comment(comment->text());
  UmlWindow::set_commented(bn);
  
  kvtable->update(bn);
  
  bn->package_modified();
  rel->modified();
  
  MyTabDialog::accept();
}

==> bouml_2.5.2.tar.gz: bouml_2.5.2/src/dialog/SimpleRelationDialog.cpp <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#include <qgrid.h> 
#include <qlabel.h>
#include <qpushbutton.h>
#include <qcombobox.h> 
#include <qmessagebox.h>
#include <qvbox.h> 

#include "SimpleRelationDialog.h"
#include "SimpleRelationData.h"
#include "BrowserSimpleRelation.h"
#include "UmlWindow.h"
#include "KeyValueTable.h"
#include "UmlPixmap.h"
#include "DialogUtil.h"
#include "strutil.h"
#include "UmlDesktop.h"

SimpleRelationDialog::SimpleRelationDialog(SimpleRelationData * r,
					   const QPoint & p)
    : MyTabDialog(r->get_browser_node()), rel(r) {  
  bool visit = !hasOkButton();
  
  UmlCode type = rel->get_type();
  
  // general tab
  
  BrowserNode * bn = rel->get_browser_node();
  QGrid * grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);

  switch (rel->get_type()) {
  case UmlInherit:
    setCaption("Generalisation dialog");
    break;
  case UmlDependOn:
    setCaption("Dependency dialog");
    break;
  default:
    setCaption("unknown relation dialog");
    break;
  }
  
  new QLabel("from : ", grid);
  new QLabel(rel->get_start_node()->full_name(TRUE), grid);
  new QLabel("to : ", grid);
  new QLabel(rel->get_end_node()->full_name(TRUE), grid);
  
  new QLabel("stereotype : ", grid);
  edstereotype = new QComboBox(!visit, grid);
  edstereotype->insertItem(rel->get_stereotype());
  if (! visit) {
    edstereotype->insertStringList(rel->get_start_node()->default_stereotypes(type));
    edstereotype->setAutoCompletion(TRUE);
  }
  edstereotype->setCurrentItem(0);
  QSizePolicy sp = edstereotype->sizePolicy();
  sp.setHorData(QSizePolicy::Expanding);
  edstereotype->setSizePolicy(sp);
  
  QVBox * vtab = new QVBox(grid);
  new QLabel("description :", vtab);
  if (! visit)
    connect(new SmallPushButton("Editor", vtab), SIGNAL(clicked()),
	    this, SLOT(edit_description()));
  comment = new MultiLineEdit(grid);
  comment->setReadOnly(visit);
  comment->setText(bn->get_comment());
  QFont font = comment->font();
  font.setFamily("Courier");
  font.setFixedPitch(TRUE);
  comment->setFont(font);
  
  addTab(grid, "Uml");
  
  // USER : list key - value
  
  grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  kvtable = new KeyValuesTable(bn, grid, visit);
  addTab(grid, "User");
  
  UmlDesktop::limitsize_move(this, 0.8, 0.8, p);
}

void SimpleRelationDialog::edit_description() {
  edit(comment->text(), "simplerelation_description",
       rel, TxtEdit, this, (post_edit) post_edit_description);
}

void SimpleRelationDialog::post_edit_description(SimpleRelationDialog * d, QString s)
{
  d->comment->setText(s);
}

void SimpleRelationDialog::accept() {
  BrowserNode * bn = rel->get_browser_node();
  
  rel->set_stereotype(edstereotype->currentText().stripWhiteSpace());
  bn->set_comment(comment->text());
  UmlWindow::set_commented(bn);
  
  kvtable->update(bn);
  
  bn->package_modified();
  rel->modified();
  
  MyTabDialog::accept();
}
